function Y=Wilson(x,T)

%*******************************************************************************
% Program written for ternary system by Stathis Skouras, 19/3/2000
% modified for binary system by Jrgen K. Johnsen, 26/1/2005
%******************************************************************************* 
% Program for binary VLE by using Wilson equation
%*******************************************************************************
% Binary system
%                (1): Methanol (light)
%                (2): Water (heavy)              
%*******************************************************************************
% Pressure is 1 atm = 1.013 bar = 760 mmHg
%*******************************************************************************
% Inputs:
% Composition vector x : row vector with NT entries
% Temperature vector T : row vector with NT entries
%
% Output:
% Y = Y=[y;T;DP];
%    y : vapor composition light component
%    T : temperature on each tray
%    DP: total gauge pressure on each tray ( = 0 )
%
%*******************************************************************************
% Data that have to be changed for different mixtures

% % Pure component constants for Antoine equation (Ghmeling et. al. 1977-1990 p.58)
% A1 = 7.97328; B1 = 1515.14;  C1 = 232.85;   % (T-range:   64C - 110C, Component 1)
% A2 = 8.07131; B2 = 1730.630; C2 = 233.426;  % (T-range:   1C - 100C, Component 2)

% Pure component constants for extended Antoine equation (Hysys)
A1 = 59.8373 ; B1 = -6282.89;  C1 = 0; D1 = -6.37873; E1 = 4.62e-6; F1 = 2;   % (T-range:   14.85C - 239.448C, Component 1)
A2 = 65.9278; B2 = -7227.53; C2 = 0; D2 = -7.17695; E2 = 4.03e-6; F2 = 2;  % (T-range:   1.85C - 374.149C, Component 2)

% Molar volumes of pure components (Gmehling et al, 1977-1990 appendix 1)
V1 = 40.73;     % Component 1 (cm^3/mol)
V2 = 18.07;     % Component 2 (cm^3/mol)

% Binary interaction parameters Aij for Wilson equation (Gmehling et al. 1977-1990 p.58)
A11 = 0;                       % Pure component 1 (cal/mol)
A22 = 0;                       % Pure component 2 (cal/mol)
A12 = -52.6055;                % Binary mixture 1-2 (cal/mol) 
A21 = 620.6314;                % Binary mixture 1-2 (cal/mol) 

% End of data that have to be changed for different mixtures 
%*******************************************************************************

% Gas constant
R = 1.98721;     % cal/(mol*K)

% Binary interaction parameters for Wilson equation 
L11 = V1/V1*exp(-A11./(R*T));            % Pure component 1 
L22 = V2/V2*exp(-A22./(R*T));            % Pure component 2 
L12 = V2/V1*exp(-A12./(R*T));            % Binary mixture 1-2 
L21 = V1/V2*exp(-A21./(R*T));            % Binary mixture 1-2 

% %Vapor pressures by Antoine equation
%  P1s = 10.^(A1-B1./(T-273.15+C1));                % Component 1 (mmHg)
%  P2s = 10.^(A2-B2./(T-273.15+C2));                % Component 2 (mmHg)

%Vapor pressures by modified Antoine equation (Used in Hysys)
%T in Kelvin, Ps in mmHg
P1s = exp(A1 + B1./(T+C1) + D1*log(T) + E1*T.^F1 )*7.5006156; %Componenet 1 (mmHg)
P2s = exp(A2 + B2./(T+C2) + D2*log(T) + E2*T.^F2 )*7.5006156; %Componenet 2 (mmHg)


% Activity coefficients by Wilson equation
G1 = exp(1-log(x.*L11+(1-x).*L12)...
          -     x.*L11./(x.*L11+(1-x).*L12)...
          - (1-x).*L21./(x.*L21+(1-x).*L22));    % Component 1

G2 = exp(1-log(x.*L21+(1-x).*L22)...
          -     x.*L12./(x.*L11+(1-x).*L12)...
          - (1-x).*L22./(x.*L21+(1-x).*L22));    % Component 2

      
% Total gauge pressure in each stage 
% Pressure is 1 atm giving DP = 0 at solution
DP = 1 - (x.*G1.*P1s + (1-x).*G2.*P2s)/760; 

% Vapor Liquid Equilibria (VLE)
y = x.*G1.*P1s./(x.*G1.*P1s + (1-x).*G2.*P2s);        % Component 1

Y = [y; T; DP];

