function xprime=column1(t,X,U) 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%  Program written by Jrgen K. Johnsen, 26/1/2005  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Column1 - This is a nonlinear model of a distillation column with
%    NT-1 theoretical stages including a reboiler (stage 1) plus a
%    total condenser ("stage" NT).
%
%    Model assumptions: 
%    1. Staged distillation column section
%    2. Two components (binary separation)
%    2. Perfect mixing and equilibrium in all stage and vessels
%    3. No vapor holdup on the stages
%    4. Linear liquid flow dynamics
%    5. Constant molar vapor flows in all stages (i.e., simplified energy balances) 
%    6. Constant pressure
%    7. Total condenser
%    8. Ideal behaviour in the vapor phase (in order to use Raoult's law)
%    9. Activity coeffisients for VLE using Wilson equation      
%
% Inputs: 
%    t - Time in [min].
%    X - State.
%        X(1:NT)      - Molar fractions of the light component A
%                       with bottom stage as X(1) and condenser as X(NT).                  
%        X(NT+1:2*NT) - Liquid holdups in the stages (including condenser + reboiler) 
%        X(2NT+1:3NT) - Temperatures in the stages (including condenser + reboiler), these
%                       are algebraic equations (i.e. T is found such that DP = 0)
%    U - Process inputs  
%        U(1) - Reflux L [kmol/min]
%        U(2) - Boilup V [kmol/min]
%        U(3) - Distillate product flow D [kmol/min]
%        U(4) - Bottom product flow B [kmol/min] 
%        U(5) - Feed rate F [kmol/min]
%        U(6) - Feed composition, zF

% Outputs:   xprime - vector with time derivative of all the states 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%------------------------------------------------------------
% Data that have to be changed for different columns:
% Number of stages: 
    NT =13;;
% Location of feed stage (stages are counted from the bottom):  
    NF = 6;; 
% Molar volumes
    V1 = 40.73;     % Molar volume methanol [dm^3/kmol]
    V2 = 18.07;     % Molar volume water [dm^3/kmol]
    
% Nominal liquid holdups  
% Boiler is 5dm^3 and x = 0.01 
% Total stage holdup is approx. 5% of total column volume, x = 0.5 
% Condenser is 0.5dm^3 and x = 0.99 
    M0        = zeros(1,NT);
    M0(1)     = 6/V2;        %Nominal boiler holdup [kmol] 
    M0(2:NF-1)= 0.06*pi*(0.25)^2*(7.5)*(0.01/V1 + 0.99/V2)/(NF-1); %Nominal stage holdups, bottom section [kmol] 
    M0(NF:NT-1)= 0.1*pi*(0.25)^2*(9.5)*(0.99/V1 + 0.01/V2)/(NT-1-NF); %Nominal stage holdups top section[kmol] 
    M0(NT)    = 0.5/V1;       %Nominal condenser holdup [kmol] 
    
% Effect of subcooled reflux and feed (assumed stationary)
% Data from HYSYS at 1atm pressure and with molefractions
% xF = 0.3095; xL = 0.99;
    TL  = 5;             %Refluxtemperature [degC]
    TbL = 65.9;          %Reflux boiling point [degC]
    TF  = 20;            %Feedtemperature [degC]
    TbF = 77.4;          %Feed boiling point [degC]
    DeltaHvapL = 3.6e4;  %Spesific heat of vaporization for reflux [kJ/kmol]
    DeltaHvapF = 4.0e4;  %Spesific heat of vaporization for feed [kJ/kmol] 
    cpL = 116.0;         %cp reflux [J/mol/K]
    cpF = 87.9;          %cp feed [J/mol/K]
    qL  = 1 + cpL*(TbL-TL)/DeltaHvapL; %Reflux liquid fraction ( > 1 => subcooled reflux)
    qF  = 1 + cpF*(TbF-TF)/DeltaHvapF; %Feed liquid fraction ( > 1 => subcooled feed)

% Data for linearized liquid flow dynamics (doesn't apply to reboiler and condenser)
    taul= 1/NT;        %Time constant for liquid dynamics above feed[min]
    tau2 = 4/NT;        %Time constant for liquid dynamics below feed[min]
    F0  = 0.0035;      %Nominal feed rate (no vaporfraction)[kmol/min] (=1ml/s x=0.3095)
    Lw0 = 0.66*60/1000; %dm^3/min
    L0  = Lw0*(0.99/V1+0.01/V2);  %Nominal reflux flow (from steady state)[kmol/min] (=0.6ml/s x=0.99)
    L0t = qL*L0; %Nominal liquid flow above feed and below reflux input
    L0b = qF*F0; %Nominal liquid flow below feed [kmol/min]

% End of data that have to be changed for different columns
%------------------------------------------------------------   

% Splitting the states
i = 1:NT;
x(i) = X(1:NT);             % Liquid composition from btm to top
M(i) = X(NT+1:2*NT);        % Liquid hold up from btm to top
T(i) = X(2*NT+1:3*NT);      % Temperature from top to btm
 
% Inputs and disturbances
LT = U(1);               % Reflux [kmol/min]
VB = U(2);                  % Boilup
D  = U(3);                  % Distillate
B  = U(4);                  % Bottoms
F  = U(5);                  % Feedrate
zF = U(6);                  % Feed composition

% THE MODEL

% Vapor-liquid equilibria (VLE)  
%opt = optimset('fsolve');
%opt = optimset(opt,'TolX',1e-9,'TolFun',1e-9);
%[T,FVAL,EXITFLAG]=fsolve(@(T) dp_wilson(x,T),T);  %solve algebraic eq. pressure=1atm to get temperature 
Y = wilson(x,T);             % Calls 'Wilson' VLE model and returns vapor composition, temperature and stage pressure

% Splitting the states
y  = Y(1,1:NT);              % Vapor composition for methanol
T  = Y(2,1:NT);              % Temperature estimation in each stage
DP = Y(3,1:NT);              % Pressure difference vector  

% Vapor flows assuming constant molar flows 
i = 1:NT-1;     V(i) = VB*ones(1,NT-1);
i = NF:NT-1;    V(i) = V(i) + (1-qF)*F;
i = NT-1;       V(i) = V(i) + (1-qL)*LT;

% Liquid flows in column sections assuming linearized tray hydraulics with
% time constant taul and tau2
i = 2:NF-1;     L(i) = L0b + (M(i)-M0(i))./tau2; 
i = NF:NT-1;    L(i) = L0t + (M(i)-M0(i))./taul;
i = NT;         L(i) = LT;

% Material balances for the column.
% 1) Overall material balances 
% 2) Component material balances

% Column part
i=2:NT-1;
dMdt(i)  = L(i+1)         - L(i)       + V(i-1)         - V(i);                   
dMxdt(i) = L(i+1).*x(i+1) - L(i).*x(i) + V(i-1).*y(i-1) - V(i).*y(i);

% Correction for feed part
i = NF;
dMdt(i)  = dMdt(i)  + F;
dMxdt(i) = dMxdt(i) + F*zF;

% Reboiler (assumed to be an equilibrium stage)
dMdt(1)  = L(2)      - V(1)      - B;
dMxdt(1) = L(2)*x(2) - V(1)*y(1) - B*x(1);

% Total condenser (not considered as an equilibrium stage)
dMdt(NT) = V(NT-1)         - LT       - D;
dMxdt(NT)= V(NT-1)*y(NT-1) - LT*x(NT) - D*x(NT);

% Compute the derivative for the mole fractions from d(Mx) = x dM + M dx
i=1:NT;
dxdt(i) = ( dMxdt(i) - x(i).*dMdt(i) )./M(i);

% Output
xprime=[dxdt';dMdt';DP'];