function xprime=column1_lv(t,X,U) 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%  Program written by Jrgen K. Johnsen, 26/1/2005  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% column1_lv - Subroutine for simulation of distillation column with LV-configuration.
%   It calls the model column1, and includes control of condenser and reboiler level 
%   using two P-controllers with the LV-configuration. 
%
% Inputs: 
%    t - Time in [min].
%    X - State.
%        X(1:NT)      - Molar fractions of the light component A
%                       with bottom stage as X(1) and condenser as X(NT).                  
%        X(NT+1:2*NT) - Liquid holdups in the stages (including condenser + reboiler) 
%        X(2NT+1:3NT) - Temperatures in the stages (including condenser + reboiler), these
%                       are algebraic equations (i.e. T is found such that DP = 0)
%    U - Process inputs  
%        U(1) - Reflux L [ml/sec]
%        U(2) - Boiler input [0-1], 1 corresponding to 3.18kW
%        U(3) - Feed rate F [ml/s]
%        U(4) - Feed composition, zF [0-1]
%
% Outputs:   xprime - vector with time derivative of all the states 

% Number of stages in the column
NT=13;

%Problem dependent parameters
q = 3.18; %boiler input gain [kW]
Q = 0.318; %net heat loss from boiler [kW]
Hvap = 4.07e4; %molar heat of vaporization for water [kJ/kmol]
V1 = 40.73;     % Molar volume methanol [dm^3/kmol]
V2 = 18.07;     % Molar volume water [dm^3/kmol]

%Giving sensible names and transform inputs to molar flows
zF = U(4);
xd = X(NT); %top composition
L  = U(1)*60/1000*(xd/V1+(1-xd)/V2);  %[kmol/min]
VB = 60*(q*U(2)-Q)/Hvap; %molar boilup      %[kmol/min]
F  = U(3)*60/1000*(zF/V1 + (1-zF)/V2);     %[kmol/min]


% P-Controllers for control of reboiler and condenser hold up.
KcB=10;  KcD=10;         % controller gains
MDs=0.5/40.73; MBs=6/18.07;   % Nominal holdups 
MB=X(NT+1); MD=X(2*NT); % Actual reboiler and condenser holdup
D=(MD-MDs)*KcD;       % Distillate flow
B=(MB-MBs)*KcB;       % Bottoms flow     

% Store all inputs and disturbances
U(1)=L; U(2)=VB; U(3)=D; U(4)=B; U(5)=F; U(6)=zF;

xprime=column1(t,X,U);